// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho...  19 agosto 2013
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas
// definido como 0.001 para POVRAY
//
// AUMC AccesoriosUtilesMaquinaCoser
// El archivo dibuja un Prensatelas con Guia de Agujas.  Su objetivo
// es agregarlo a una o varias Maquinas de Coser que se
// disenaran posteriormente.  Es poco flexible, pero permite
// controlar su movimiento.
//
// La macro tiene cuatro parametros.
// #macro AUMC_PrensatelasGuiaAguja( FraccionDescensoAguja,
//         FraccionAscensoPrensatelas, Balanceo, FraccionMovimientoInferior )
//      FraccionDescensoAguja           : Fraccion entre 0 y 1
//                      para bajar la aguja.
//      FraccionAscensoPrensatelas      : Fraccion entre 0 y 1
//                      para subir el prensatelas.  El modelo real
//                      tiene topes en 0, 0.4.  Con presion se llega
//                      al valor de 1.0 pero se devuelve a 0.4 al soltar.
//      Balanceo                        : Vector para aplicar
//                      rotate al Prensatelas Universal inferior.
//      FraccionMovimientoInferior      : Fraccion entre 0 y 1
//                      que desplaza las guias dentadas inferiores hacia Z-.
//
// Las caracteristicas del objeto son:
//      Soportes Superiores     : 45*L en Y ( semicentrados en dicho plano )
//      AlturaMaximaY           : 72.5*L
//      AlturaMinimaY           : -11*L
//      FrenteX                 : -21.5*L..+30L
//      ProfundidadZ            : -16*L..25*L
//      GruesoPlaca             : 1.4*L
// Se supone que la aguja cae desde Y+ con gravedad Y-, y atravieza el origen de
// coordenadas.  La placa se coloca directamente bajo el plano XZ.
// La costurera se sienta hacia Z-, y mira el aparato hacia Z+.
//
// Estas son variables predefinidas o generadas en el
// interior de las macros que no deberian modificarse directamente.
// Si quiere cambiarlas, recurra a los modificadores.
// #declare AUMC_TexturaMetalica
//      Textura principal a aplicar a las estructuras.
// #declare AUMC_TexturaNegra
//      Textura auxiliar para zonas en negro.
// #declare AUMC_TexturaDentada
//      Textura a aplicar a las guias dentadas inferiores.  Los dientes,
//      surgen como efecto visual de la textura.
// #declare AUMC_FraccionPrimerTope
//      Retorna el valor 0.4, que es el tope superior estable permitido
//      en el modelo real para el parametro FraccionAscensoPrensatelas.
//      Permite hasta el valor de 1.0 pero retorna al soltar.  
// #declare AUMC_AlturaGuiaSuperior
//      Altura en Y como real para ubicar los soportes
//      superiores del prensatelas.
// #declare AUMC_VolumenBase
//      Objeto sin textura generado en la macro.  Sirva para perforar
//      superficies y ubicar la base del objeto.  Las coordenadas Y
//      son excesivas a la verdadera placa.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)
// #declare AUMC_DefaultTexturaMetalica                 = texture  { ... }
//      Textura principal a aplicar a las estructuras.             
// #declare AUMC_DefaultTexturaNegra                    = texture  { ... }
//      Textura auxiliar para zonas en negro.
// #declare AUMC_DefaultTexturaDentada                  = texture  { ... }
//      Textura a aplicar a las guias dentadas inferiores.  Los dientes,
//      surgen como efecto visual de la textura.
// #declare AUMC_POV3_1                                 = off;
//      Valor on activa modo de compatibilidad con POVRay 3.1.
//      En algunas versiones se activara automaticamente.
//      En esta version no cumple ninguna funcion.
//
// Para colocarlo simplemente
// #include "AUMC.inc"
// object        { AUMC_PrensatelasGuiaAguja( 0,0,0,0 ) }
//
// Otro ejemplo con modificador
// #include "AUMC.inc"
// #declare AUMC_DefaultTexturaMetalica        = texture       {
//   average
//   texture_map        {
//     [ 0.5 AUMC_TexturaMetalica ]
//     [ 0.5 Rust                 ]
//   }
// }
// object        {
//   AUMC_PrensatelasGuiaAguja( 0,0,0,0 )
// }
//

#include "metals.inc"
#declare AUMC_L                 = 0.001;
#declare AUMC_FraccionPrimerTope        = 0.4;

#if ( version < 3.2 )
  #ifndef( AUMC_POV3_1 )
    #declare AUMC_POV3_1        = on;
  #end
#else
  #ifndef( AUMC_POV3_1 )
    #declare AUMC_POV3_1        = off;
  #end
#end


#declare AUMC_TexturaMetalica                   = texture       {
  T_Chrome_3B
  normal                {
    bumps
    scale  0.10
  }
}

#declare AUMC_DefaultTexturaMetalica            = texture       {
  AUMC_TexturaMetalica
}

#declare AUMC_TexturaDentada                   = texture       {
  T_Chrome_3B
  normal                {
    gradient y
    triangle_wave
    scale  0.001
  }
}

#declare AUMC_DefaultTexturaDentada            = texture       {
  AUMC_TexturaDentada
}

#declare AUMC_TexturaNegra                      = texture       {
  pigment               {
    Mica
  }
  normal                {
    bumps
    scale  0.10
  }
}

#declare AUMC_DefaultTexturaNegra               = texture       {
  AUMC_TexturaNegra
}

#macro AUMC_PrensatelasUniversal( AnguloBalanceo, TexturaMetalica )
  union                         {
    #local L                    = AUMC_L;
    #local FrenteUsual          = 11.0*L;
    #local Grueso               = 1.25*L;
    #local ProfundidadBase      = 15.5*L;
    #local RadioTrineo          = 4*L;
    #local AltoSoporte          = 3.2*L;
    #local ProfundidadSoporte   = 8*L;
    #local ProfundidadGuia      = 5.4*L;
    // Placa Inferior
    difference                  {
      union                     {
        box                     {
          < -FrenteUsual/2,      0,                0 >,
          < +FrenteUsual/2, Grueso, -ProfundidadBase >
        }
        // Trineo delantero derecho
        difference              {
          cylinder              {
            -FrenteUsual/2*x, +FrenteUsual/2*x, RadioTrineo
          }
          cylinder              {
            -FrenteUsual  *x, +FrenteUsual  *x, RadioTrineo-Grueso
            scale               <1,1,
                     ( RadioTrineo-0.5*Grueso )/( RadioTrineo-Grueso ) >
          }
          plane                 {
            -z, 0
          }
          plane                 {
            -y, 0
          }
          plane                 {
            x ,0
            rotate      -45*y
            translate   +0.025*FrenteUsual*x
          }
          translate             -ProfundidadBase*z+RadioTrineo*y
        }  // Trineo delantero derecho
        // Trineo delantero izquierdo
        difference              {
          cylinder              {
            -FrenteUsual/2*x, +FrenteUsual/2*x, RadioTrineo
          }
          cylinder              {
            -FrenteUsual  *x, +FrenteUsual  *x, RadioTrineo-Grueso
            scale               <1,1,
                     ( RadioTrineo-0.5*Grueso )/( RadioTrineo-Grueso ) >
          }
          plane                 {
            -z, 0
          }
          plane                 {
            -y, 0
          }
          plane                 {
            -x ,0
            rotate      +45*y
            translate   -0.025*FrenteUsual*x
          }
          translate             -ProfundidadBase*z+RadioTrineo*y
        }  // Trineo delantero izquierdo
        // Trineo posterior
        difference              {
          cylinder              {
            -FrenteUsual/2*x, +FrenteUsual/2*x, RadioTrineo
          }
          cylinder              {
            -FrenteUsual  *x, +FrenteUsual  *x, RadioTrineo-Grueso
          }
          plane                 {
            +z, 0
          }
          plane                 {
            -y, 0
            rotate              45*x
          }
          translate             +RadioTrineo*y
        }  // Trineo posterior
      }  // union
      // hendiduras de la base
      box                       {
        < -0.025*FrenteUsual,   -Grueso, -0.70*ProfundidadBase >,
        < +0.025*FrenteUsual, +2*Grueso, -1.1*ProfundidadBase >
      }
      box                       {
        < -0.20*FrenteUsual, -Grueso, -1.15*ProfundidadSoporte >,
        < +0.20*FrenteUsual, +2*Grueso, -0.70*ProfundidadBase >
      }
      box                       {
        < -0.20*FrenteUsual,         0, -1.15*ProfundidadSoporte >,
        < +0.20*FrenteUsual, +2*Grueso, -0.70*ProfundidadBase >
        translate               +0.70*ProfundidadBase*z
        rotate                  -70*x
        translate               -0.70*ProfundidadBase*z
      }
      cylinder                  {
        -Grueso*y, +2*Grueso*y,
        ( -1.15*ProfundidadSoporte+0.70*ProfundidadBase )/2
        translate               -0.20*FrenteUsual*x+
                       ( -0.575*ProfundidadSoporte-0.35*ProfundidadBase )*z
      }
      cylinder                  {
        -Grueso*y, +2*Grueso*y,
        ( -1.15*ProfundidadSoporte+0.70*ProfundidadBase )/2
        translate               +0.20*FrenteUsual*x+
                       ( -0.575*ProfundidadSoporte-0.35*ProfundidadBase )*z
      }
      translate                 +ProfundidadGuia*z
    }  // difference
    // Soporte y barrita
    union                       {
      // Barrita
      cylinder                  {
        -0.4*FrenteUsual*x, +0.4*FrenteUsual*x, AltoSoporte/8
        translate               +AltoSoporte/2*y
      }
      // Soporte de Barrita
      difference                {
        prism                   {
          -0.45*FrenteUsual, +0.45*FrenteUsual, 5
          < 0, +ProfundidadGuia >,
          < AltoSoporte, +0.8*ProfundidadGuia >,
          < AltoSoporte, 0.5*( -ProfundidadSoporte+ProfundidadGuia ) >,
          < 0, ( -ProfundidadSoporte+ProfundidadGuia ) >,
          < 0, +ProfundidadGuia >
          rotate                +90*z
        }
        box                     {
          <-0.25*FrenteUsual, -Grueso, +1.1*ProfundidadGuia >,
          <+0.25*FrenteUsual, AltoSoporte+Grueso, -1.1*ProfundidadSoporte >
        }
        cylinder                  {
          -0.6*FrenteUsual*x, +0.6*FrenteUsual*x, AltoSoporte/8
          translate               +AltoSoporte/2*y
        }
      }
      translate                 +Grueso*y
    }
    translate                   -( Grueso+AltoSoporte/2 )*y
    rotate                      AnguloBalanceo
    #declare AUMC_PuntoGuiaAguja        =
                -( Grueso+AltoSoporte/2 )*y
      -0.5*( 1.15*ProfundidadSoporte+0.7*ProfundidadBase-2*ProfundidadGuia )*z;
    texture                     {
      TexturaMetalica
    }
  }
#end  // #macro AUMC_PrensatelasUniversal

#macro AUMC_Aguja( TexturaMetalica )
  difference                    {
    #local L                    = AUMC_L;
    #local EjeCilindroSuperior  = 7.2*L;
    #local EjeCilindroTotal     = 25*L;
    #local Ojo                  = 1.5*L;
    #local Punta                = 2.5*L;
    #local RadioMenor           = 0.7/2*L;
    #local RadioMayor           = 1.4/2*L;
    // Forma Simetria Cilindrica
    union                       {
      sphere                    {
        EjeCilindroTotal*y, RadioMayor
      }
      cylinder                  {
        0, EjeCilindroTotal*y, RadioMenor
      }
      cylinder                  {
        EjeCilindroTotal*y, ( EjeCilindroTotal-EjeCilindroSuperior )*y,
        RadioMayor
      }
      cone                      {
        ( EjeCilindroTotal-EjeCilindroSuperior )*y, RadioMayor,
        ( EjeCilindroTotal-EjeCilindroSuperior-10*RadioMenor )*y
        RadioMenor
      }
      cone                      {
        0, RadioMenor,
        -Punta*y, 0
      }
      translate                 -Ojo/2*y
    }
    // Base plana posterior
    plane                       {
      -z, -RadioMenor
    }
    // Ojo Aguja
    cylinder                    {
      -RadioMayor*z, RadioMayor*z, Ojo/2
      scale                     0.33*x
    }
    #declare AUMC_GuiaAgujaVertical     = EjeCilindroTotal
        -0.75*EjeCilindroSuperior
        -Ojo/2;
    texture                     {
      TexturaMetalica
    }
  }
#end

#macro AUMC_SoporteAguja
   ( FraccionDescenso, FraccionGiroTuerca, TexturaMetalica )
  union                         {
    #local L                    = AUMC_L;
    #local RadioTuerca          = 1.43/2*L;
    #local LadoCuadrado         = 6.4*L;
    #local AltoCuadrado         = 3.6*L;
    #local RadioInterior        = 4.3/2*L;
    #local GiroTuerca           = FraccionGiroTuerca+3;
    #local RadioMayorAguja      = 0.7*L;
    #local AltoVariable         = 26*L;
    #local AltoFijo             = 9*L;
    // BaseCubica
    union                       {
      cylinder                  {
        3*LadoCuadrado/2*x,0.95*LadoCuadrado/2*x,
        0.75*AltoCuadrado/2
        translate               -( LadoCuadrado-AltoCuadrado )*z/2
      }

      difference                {
        superellipsoid          {
          <0.2,0.2>
          scale                 < LadoCuadrado, AltoCuadrado, LadoCuadrado >/2
        }
        cylinder                {
          -AltoCuadrado*y, +AltoCuadrado*y,
          RadioInterior
        }
      }  // difference
      //  PlaquitaLateral
      box                       {
        <-LadoCuadrado/2,-1.2*AltoCuadrado/2,-LadoCuadrado/2>,
        <-LadoCuadrado/2-0.05*LadoCuadrado,
         +AltoCuadrado/2,+LadoCuadrado/2>
      }
      //  PlaquitaInferior
      difference                {
        box                     {
          <-LadoCuadrado/2-0.05*LadoCuadrado, -1.2*AltoCuadrado/2, 0 >,
          <+LadoCuadrado/2,-1.30*AltoCuadrado/2, -LadoCuadrado/2 >
        }
        cylinder                {
          -AltoCuadrado*y, 0, RadioMayorAguja
        }
      }
    }  // BaseCubica
    // Cilindro Sube Y Baja
    union                       {
      // CajitaSuperior
      box                       {
        < -LadoCuadrado/2, 0, -LadoCuadrado/2 >,
        < +LadoCuadrado/2, AltoCuadrado, +LadoCuadrado/2 >
        translate               ( AltoFijo-AltoCuadrado/2 )*y
        translate               FraccionDescenso*AltoVariable*y
        #declare AUMC_DescensoVerticalSoporte   = //-Al
                        AltoFijo+AltoVariable*FraccionDescenso;
        
      }
      // Cilindro propiamente
      difference                {
        cylinder                {
          0, ( AltoVariable+AltoFijo+AltoCuadrado )*y,
          RadioInterior
        }
        cylinder                {
          0, 5*AltoCuadrado*y/2, RadioMayorAguja
        }
        box                     {
          < -RadioMayorAguja, -RadioMayorAguja, 0 >,
          < +RadioMayorAguja, 2*AltoCuadrado, -2*RadioInterior >
        }
        box                     {
          < -RadioInterior, 2*AltoCuadrado, 0 >,
          < +RadioInterior, 5*AltoCuadrado/2, -2*RadioInterior >
        }
        cylinder                {
          -2*RadioInterior*z, +2*RadioInterior*z, RadioMayorAguja
          translate             3*AltoCuadrado*y
        }
        translate               -1.30*AltoCuadrado/2*y
      }  // Cilindro propiamente
    }
    // TuercaMetalica
    difference                  {
      // FormaTuerca
      union                     {
        // Guia Tuerca
        cylinder                {
          0, -7*RadioTuerca*x, RadioTuerca
        }
        // Cabeza Tuerca
        union                   {
          cylinder                {
            -RadioTuerca*z, RadioTuerca*z, 2*RadioTuerca
          }
          torus                 {
            2*RadioTuerca, RadioTuerca
            rotate              90*x
          }
          scale                 <0.75,1,1>
          translate             2*0.75*RadioTuerca*x
        }
      }
      // Muesca
      box                       {
        < 0, -RadioTuerca/2, -2*RadioTuerca >,
        < 3*RadioTuerca, +RadioTuerca/2, +2*RadioTuerca >
        translate               2*0.80*RadioTuerca*x
      }
      // Simulacion Rosca
      #local C                  = 0;
      #while ( C < 20 )
        torus                   {
          RadioTuerca, 0.10*RadioTuerca
          rotate                90*z
          translate             -( C+3 )*0.2*RadioTuerca*x
        }
        #local C                = C+1;
      #end
      rotate                    -360*GiroTuerca*x
      translate                 +0.2*GiroTuerca*RadioTuerca*x
      translate                 -( LadoCuadrado-AltoCuadrado )*z/2
                                +3.2*LadoCuadrado/2*x
    }
    texture                     {
      TexturaMetalica
    }
  }
#end

#macro AUMC_SoportePrensatelas
   ( FraccionAscenso, TexturaMetalica, TexturaNegra )
  union                         {
    #local L                    = AUMC_L;
    #local Profundidad          = 2.5*L;
    #local AltoVariable         = 10*L;
    #local AltoVisible          = 39*L;
    // Forma Base
    difference                  {
      prism                     { cubic_spline
        -Profundidad/2, +Profundidad/2, 23,
        <0,-1>*L/2,
        < 0, -2 >*L,
        < 3.6, -2 >*L,
        < 3.6, +1.4 >*L,
        < 10.7, +1.4 >*L,
        < 10.7, +3.6 >*L,
        < 7.1, +3.6 >*L,
        < 7.1, 5.7 >*L,
        < 10.7, 5.7 >*L,
        < 10.7, 8.6 >*L,
        < 15.8, 8.6 >*L,
        < 17, +14 >*L,
        < 10.7, 14 >*L,
        < 10, 13.2 >*L,
        < 6.4, 13.2>*L,
        < 3.0, 2.9 >*L,
        < 0, 2.9 >*L,
        < 0, 1 >*L/2,
        < 2, 1 >*L/2,
        < 2, -1 >*L/2,
        < 0, -1 >*L/2,
        < 0, -2 >*L,
        <3.6,-2>*L
        
        rotate          90*z
      }
      box                       {
        < -0.9*Profundidad/2, 4.0*L, -7*L >,
        < -1.1*Profundidad/2, 0, +7*L >
        texture { TexturaMetalica normal { bumps scale 0.1 } }
      }
      cylinder                  {
        -Profundidad*x, +Profundidad*x,
        0.5*L
        scale                   <1,1,4>
        translate               16.5*L*y+12.0*L*z
      }
      cylinder                  {
        -Profundidad*x, +Profundidad*x,
        1*L
        translate               12.0*L*z+10.0*L*y
      }
      box                       {
        < 0, 0, 3.0*L >,
        < Profundidad, 10*Profundidad, 6.25*L >
        texture { TexturaNegra }
      }
    }
    prism                       { cubic_spline
      -Profundidad/6, +Profundidad/6, 13,
      <0,-2>*L,
      <0.75,0>*L,
      <0.75, 4.0>*L
      <8.5,7.0>*L,
      <8.5,8.5>*L,
      <6.5,7.0>*L,
      <-0.75,5>*L,
      <-0.75,0>*L,
      <-3,3>*L,
      <-4.5,3>*L,
      <0,-2>*L,
      <0.75,0>*L,
      <0.75,4.0>*L
      rotate                    90*z
      translate                 12.0*L*z+10.0*L*y
    }
    cylinder                    {
      6.5*L*y+16.0*L*z, 0, Profundidad/24
      texture                   {
        TexturaNegra
      }
    }
    // Columna Sube y Baja
    union                       {
      #local RadioSubeBaja      =
                 sqrt( Profundidad*Profundidad/4+1.4*1.4*L*L );
      box                       {
        <0,0,-1.4*L>,
        <Profundidad/2,AltoVisible,+1.4*L>
      }
      cylinder                  {
        0.35*AltoVisible*y, AltoVisible*y, RadioSubeBaja
      }
      difference                {
        cylinder                {
          0, AltoVisible*y, RadioSubeBaja
        }
        cylinder                {
          0, RadioSubeBaja*x, 1*L
          translate 5*L*y
          texture               { TexturaNegra }
        }
        plane                   {
          x, Profundidad/2
        }
      }
      translate                 3.6*L*y+4.7*L*z
    }  // union
    // Cilindro superior
    cylinder                    {
      -Profundidad/2*y, Profundidad/2*y, RadioSubeBaja*2
      translate                 AltoVisible*y
      translate                 3.6*L*y+4.7*L*z
      translate                 -FraccionAscenso*AltoVariable*y
      #declare AUMC_GuiaVerticalSoportePrensatelas  =
          AltoVisible-FraccionAscenso*AltoVariable+3.6*L;
      #declare AUMC_GuiaVerticalAscenso             =
          FraccionAscenso*AltoVariable;
    }
    // Tornillo Fijar
    difference                  {
      cylinder                  {
        -Profundidad/2*x, -Profundidad*x, RadioSubeBaja
        translate               8.6*L*y+4.7*z*L
      }
      box                       {
        <0,-0.1*RadioSubeBaja,-RadioSubeBaja>,
        <0.4*Profundidad,+0.1*RadioSubeBaja,RadioSubeBaja>
        rotate                  30*x
        translate               8.6*L*y+4.7*z*L-Profundidad*x
        texture                 { TexturaNegra }
      }
    }
    // Cilindro Superior
    texture                     {
      TexturaMetalica
    }
    translate                   -0.6*L*y
  }  // union
#end  // #macro AUMC_SoportePrensaTelas

#macro AUMC_BaseInferior
  ( FraccionMovimiento, TexturaMetalica, TexturaDentada )
  union                         {
    #local L                    = AUMC_L;
    #local BaseTrapecio         = 51.5*L;
    #local BaseMenor            = 46.5*L;
    #local AltoTrapecio         = 37*L;
    #local GruesoPlaca          = 1.4*L;
    #local GuiaAgujaY           = 14.6*L;
    #local GuiaAgujaX           = 21.5*L;
    #local FrentePerforado      = 10.7*L;
    #local AltoPerforado        = 2*FrentePerforado;
    #local AgujaPerforado       = 8.6*L;
    // Base perforada
    #declare AUMC_VolumenBase   =
       prism                     {
        linear_spline
        -GruesoPlaca, 2*GruesoPlaca, 7,
        < -BaseTrapecio/2, 0 >,
        < 0,-0.05*AltoTrapecio >,
        < +BaseTrapecio/2, 0 >,
        < +BaseMenor/2, AltoTrapecio >,
        < 0, 1.05*AltoTrapecio >,
        < -BaseMenor/2, AltoTrapecio >,
        < -BaseTrapecio/2, 0 >
        rotate          -90*x
        translate               -GuiaAgujaY*y
        translate               ( BaseTrapecio/2-GuiaAgujaX )*x
      }
      
   difference                  {
      prism                     {
        linear_spline
        0, GruesoPlaca, 7,
        < -BaseTrapecio/2, 0 >,
        < 0,-0.05*AltoTrapecio >,
        < +BaseTrapecio/2, 0 >,
        < +BaseMenor/2, AltoTrapecio >,
        < 0, 1.05*AltoTrapecio >,
        < -BaseMenor/2, AltoTrapecio >,
        < -BaseTrapecio/2, 0 >
        rotate          -90*x
        translate               -GuiaAgujaY*y
        translate               ( BaseTrapecio/2-GuiaAgujaX )*x
      }
      #local C                  = 0;
      #while ( C < 2 )
        union                   {
          #local DeltaPerforado = FrentePerforado/11;
          cylinder              {
            -2*GruesoPlaca*z, 2*GruesoPlaca*z, DeltaPerforado
            translate           -FrentePerforado*x-0.1*AltoPerforado*y
          }
          box                   {
            < -FrentePerforado/2, 0, -2*GruesoPlaca >,
            < -FrentePerforado/2+2*DeltaPerforado,
                        AltoPerforado, 2*GruesoPlaca >
            translate           -AgujaPerforado*y
          }
          box                   {
              < -FrentePerforado/2+3*DeltaPerforado, 0, -2*GruesoPlaca >,
              < -FrentePerforado/2+5*DeltaPerforado,
                        AgujaPerforado-2*DeltaPerforado, 2*GruesoPlaca >
              translate           -AgujaPerforado*y
          }
          box                   {
            < -FrentePerforado/2+3*DeltaPerforado,
                        AgujaPerforado+2*DeltaPerforado, -2*GruesoPlaca >,
            < -FrentePerforado/2+5*DeltaPerforado,
                        AltoPerforado, 2*GruesoPlaca >
            translate           -AgujaPerforado*y
          }
          box                   {
            < -FrentePerforado/2+3*DeltaPerforado,
                        -DeltaPerforado, -2*GruesoPlaca >,
            < -FrentePerforado/2+6*DeltaPerforado,
                        +DeltaPerforado, 2*GruesoPlaca >
          }
          #if ( C = 1 )
            scale               <-1,1,1>
          #end
        }
      union                     {
        torus                   {
          2*DeltaPerforado, DeltaPerforado/4
          rotate                  90*x
        }
        cylinder                {
          2*DeltaPerforado*y, -2*DeltaPerforado*y, DeltaPerforado/4
          rotate        20*z
        }
        #if ( C = 0 )
          translate               -0.7*GuiaAgujaX*x+AltoPerforado/10*y
          translate               -GruesoPlaca*z
        #else
          translate               +1.15*GuiaAgujaX*x+0.7*AltoPerforado*y
          translate               -GruesoPlaca*z
        #end
      }
        #local C                = C+1;
      #end
      #local C                  = 0;
      #while ( C < 6 )
        cylinder                {
          0, 0.95*AltoPerforado*y, DeltaPerforado/8
          translate             -GruesoPlaca*z-AgujaPerforado*y
          translate             ( 7+2*C )*DeltaPerforado*x
          #if ( mod( C, 2 ) = 1 )
            translate           +0.05*AltoPerforado*y
          #end
        }
        #local C                = C+1;
      #end
    }
    // Arratre Dentado
    #local BordeDentado         = 0.2*DeltaPerforado;
    #local C                    = 0;
    #while ( C < 2 )
      union                     {
        box                   {
          < -FrentePerforado/2+BordeDentado, AgujaPerforado/2, -GruesoPlaca >,
          < -FrentePerforado/2+2*DeltaPerforado-BordeDentado,
                        AltoPerforado-2*BordeDentado, 2*GruesoPlaca >
          translate           -AgujaPerforado*y
        }
        box                   {
          < -FrentePerforado/2+3*DeltaPerforado+BordeDentado,
                AgujaPerforado/2, -GruesoPlaca >,
          < -FrentePerforado/2+5*DeltaPerforado-BordeDentado,
                        AgujaPerforado-2*DeltaPerforado-2*BordeDentado,
                        2*GruesoPlaca >
          translate           -AgujaPerforado*y
        }
        box                   {
          < -FrentePerforado/2+3*DeltaPerforado+BordeDentado,
                        3*AgujaPerforado/2+2*DeltaPerforado, -GruesoPlaca >,
          < -FrentePerforado/2+5*DeltaPerforado-BordeDentado,
                        AltoPerforado-2*BordeDentado, 2*GruesoPlaca >
          translate           -AgujaPerforado*y
        }
        #if ( C = 1 )
          scale                 <-1,1,1>
        #end
        texture                 {
          TexturaDentada
        }
        translate               -FraccionMovimiento*
                ( AgujaPerforado/2-2*BordeDentado )*y
      }
      #local C                  = C+1;
    #end
    texture                     {
      TexturaMetalica
    }
  }  // union
#end   // #macro AUMC_BaseInferior

#macro AUMC_PrensatelasGuiaAguja( FraccionDescensoAguja,
           FraccionAscensoPrensatelas, Balanceo, FraccionMovimientoInferior )
union                           {
  union                           {
    union                         {
      object                          {
        AUMC_SoportePrensatelas( FraccionDescensoAguja,
                        AUMC_DefaultTexturaMetalica, AUMC_DefaultTexturaNegra )
      }
      object                      {
        AUMC_PrensatelasUniversal( Balanceo, AUMC_DefaultTexturaMetalica )
      }
      translate                   -AUMC_PuntoGuiaAguja
    }
    union                         {
      object                      {
        AUMC_SoporteAguja(FraccionAscensoPrensatelas,0.15,
                        AUMC_DefaultTexturaMetalica)
      }
      object                      {
        AUMC_Aguja( AUMC_DefaultTexturaMetalica )
        translate                 -AUMC_GuiaAgujaVertical*y
      }
      translate
         ( AUMC_GuiaVerticalSoportePrensatelas-AUMC_PuntoGuiaAguja.y
          -AUMC_DescensoVerticalSoporte )*y
    }
    translate             AUMC_GuiaVerticalAscenso*y
  //  translate     -0.4*y
  }
  
  object                  {
    AUMC_BaseInferior(FraccionMovimientoInferior,
       AUMC_DefaultTexturaMetalica,AUMC_DefaultTexturaDentada)
    translate             +1.4*AUMC_L*z
    rotate                90*x
  }
  #declare AUMC_VolumenBase     =
    object                      {
      AUMC_VolumenBase
      translate         +1.4*AUMC_L*z
      rotate            90*x
    }
  #declare AUMC_AlturaGuiaSuperior      = 45*AUMC_L;  
}
#end



