// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho...  1 julio 2013
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//
// HEDA HornoElectricoDomesticoAjustable
// El archivo dibuja un Horno con funcionalidad de Tostador y Parrilla.
// De escaso volumen, para uso Domestico.
//
// La macro default tiene cuatro parametros
// #macro HEDA_Horno( AnguloPerilla1, AnguloPerilla2,
//                FactorPuerta, FactorBandeja )
//      AnguloPerilla1          : Angulo en grados para rotar la perilla
//              superior a partir de la vertical.
//      AnguloPerilla2          : Angulo en grados para rotar la perilla
//              inferior a partir de la vertical.
//      FactorPuerta            : Fraccion propia para indicar la apertura
//              del horno.  0 cerrado a menos de 1 abierto.  No utilice 1,
//              de lo contrario la puerta se abre paralela al piso y lo
//              perfora (defecto).
//      FactorBandeja           : Fraccion para desplazar la rejilla y
//              bandeja hacia afuera.  La bandeja se desplaza mas que
//              la rejilla.  0 para aparato cerrado, 1 para un
//              desplazamiento de la bandeja igual a su propio ancho.
//
// Las dimensiones del horno tostador cerrado son:
//      Alto total              =   120.0*L
//      Frente                  =  -132.0*L..+140.0*L
//      Profundidad             =   165.0*L
// Se dibuja sobre el plano XZ hemisferio positivo
// y sobre el plano XY hemisferio negativo
// parcialmente centrado en el origen.
// El frente sobresale en direccion Z-, con gravedad Y-.
//
// La siguiente macro permite mayor flexibilidad:
// #macro HEDA_HornoElectricoDomesticoAjustable(
//    AnguloPerilla1, AnguloPerilla2, FactorPuerta, FactorBandeja,
//    FrenteBasico, AltoBasico, ProfundidadBasico,
//    GruesoPared, DiametroPerilla,
//    TexturaPrincipal, TexturaMetal, TexturaCeramica, MaterialIncandescente,
//    TexturaInferiorTapa, TexturaSuperiorTapa, MaterialVidrio,
//    TexturaIndicador, TexturaPatas )
//      AnguloPerilla1          : Angulo en grados para rotar la perilla
//              superior a partir de la vertical.
//      AnguloPerilla2          : Angulo en grados para rotar la perilla
//              inferior a partir de la vertical.
//      FactorPuerta            : Fraccion propia para indicar la apertura
//              del horno.  0 cerrado menos de 1 abierto.  No utilice 1,
//              de lo contrario la puerta se abre paralela al piso y lo
//              perfora (defecto).
//      FactorBandeja           : Fraccion para desplazar la rejilla y
//              bandeja hacia afuera.  La bandeja se desplaza mas que
//              la rejilla.  0 para aparato cerrado, 1 para un
//              desplazamiento de la bandeja igual a su propio ancho.
//      FrenteBasico            : Frente del horno.  Default es 264*L.
//      AltoBasico              : Alto del horno sin patas.  Default es 114*L.
//      ProfundidadBasico       : Referencia para la profundidad Z
//              del horno.  Default es 157*L.
//      GruesoPared             : Grueso control para volumen de paredes
//              metalicas con capas de aire aislante al resto
//              de la estructura.  Default es 6*L.
//      DiametroPerilla         : Diametro de las perillas de control.
//              Default es 28.5*L.
//      TexturaPrincipal        : Textura principal a aplicar al aparato.
//              Default es HEDA_TexturaPrincipal.
//      TexturaMetal            : Textura metalica del horno.
//              Default es HEDA_TexturaMetal.
//      TexturaCeramica         : Textura para la ceramica que sostiene
//              los bulbos incandescentes.  Default es HEDA_TexturaCeramica.
//      MaterialIncandescente   : Material a aplicar a los bulbos
//              incandescentes.  Default es HEDA_MaterialIncandescente.
//      TexturaInferiorTapa     : Textura para el decorado inferior de
//              la tapa.  Default es HEDA_TexturaInferiorTapa.
//      TexturaSuperiorTapa     : Textura para el decorado superior de
//              la tapa.  Default es HEDA_TexturaSuperiorTapa.
//      MaterialVidrio          : Material para el vidrio de la tapa.
//              Default es HEDA_MaterialVidrio.
//      TexturaIndicador        : Textura para el indicador rojo
//              superior derecho del horno.
//              Default es HEDA_TexturaIndicador.
//      TexturaPatas            : Textura para las patas.
//              Default es HEDA_TexturaPatas.
//
// Estas son variables predefinidas o generadas en el
// interior de las macros que no deberian modificarse directamente.
// Si quiere cambiarlas, recurra a los modificadores.
// #declare HEDA_DefaultTexturaPrincipal
//      Textura principal a aplicar al aparato.
// #declare HEDA_DefaultTexturaMetal
//      Textura metalica del horno.
// #declare HEDA_DefaultTexturaCeramica
//      Textura para la ceramica que sostiene los bulbos incandescentes.
// #declare HEDA_DefaultMaterialIncandescente
//      Material a aplicar a los bulbos incandescentes.
// #declare HEDA_DefaultTexturaInferiorTapa
//      Textura para el decorado inferior de la tapa.
// #declare HEDA_DefaultTexturaSuperiorTapa
//      Textura para el decorado superior de la tapa.
// #declare HEDA_DefaultMaterialVidrio
//      Material para el vidrio de la tapa.
// #declare HEDA_DefaultTexturaIndicador
//      Textura para el indicador rojo superior derecho del horno.
// #declare HEDA_DefaultTexturaPatas
//      Textura para las patas.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)
// #declare HEDA_TexturaPrincipal               = texture  { ... }
//      Textura principal a aplicar al aparato.
// #declare HEDA_TexturaMetal                   = texture  { ... }
//      Textura metalica del horno.
// #declare HEDA_TexturaCeramica                = texture  { ... }
//      Textura para la ceramica que sostiene los bulbos incandescentes.
// #declare HEDA_MaterialIncandescente          = material { ... }
//      Material a aplicar a los bulbos incandescentes.
// #declare HEDA_TexturaInferiorTapa            = texture  { ... }
//      Textura para el decorado inferior de la tapa.
// #declare HEDA_TexturaSuperiorTapa            = texture  { ... }
//      Textura para el decorado superior de la tapa.
// #declare HEDA_MaterialVidrio                 = material { ... }
//      Material para el vidrio de la tapa.
// #declare HEDA_TexturaIndicador               = texture  { ... }
//      Textura para el indicador rojo superior derecho del horno.
// #declare HEDA_TexturaPatas                   = texture  { ... }
//      Textura para las patas.
// #declare HEDA_BanderaTexto                   = on;
//      Si se inactiva "off" no dibuja los textos, ni los puntos
//      negros de control de las perillas.
// #declare HEDA_ColorTexto                     = Black;
//      Para cambiar el color de texto y marcas de control en perillas.
// #declare HEDA_StringMarca                    = "POV-Ray"
//      Permite cambiar el logo text de la supuesta marca del aparato.
// #declare HEDA_POV3_1                         = off;
//      Valor on activa modo de compatibilidad con POVRay 3.1.
//      En algunas versiones se activara automaticamente.
//      En esta version no cumple ninguna funcion.
//
// Para colocarlo simplemente
// #include "HEDA.inc"
// object        { HEDA_Horno( 0, 0, 0, 0 ) }
//
// Otro ejemplo con modificador
// #include "HEDA.inc"
// #declare HEDA_TexturaPrincipal        = texture       {
//   average
//   texture_map        {
//     [ 0.5 HEDA_DefaultTexturaPrincipal ]
//     [ 0.5 Rust                         ]
//   }
// }
// object        {
//   HEDA_Horno( 0, 0, 0, 0 )
// }
//
// Un ejemplo con la macro detallada
// #include "HEDA.inc"
// object               {
//   HEDA_HornoElectricoDomesticoAjustable
//    ( 0, 0, 0, 0, 0.264, 0.114, 0.157, 0.006, 0.0285,
//      HEDA_TexturaPrincipal, HEDA_TexturaMetal,
//      HEDA_TexturaCeramica, HEDA_MaterialIncandescente,
//      HEDA_TexturaInferiorTapa, HEDA_TexturaSuperiorTapa,
//      HEDA_MaterialVidrio, HEDA_TexturaIndicador, HEDA_TexturaPatas )
// }
//

#include "textures.inc"
#include "glass.inc"

#declare HEDA_BanderaTexto              = on;
#declare HEDA_ColorTexto                = Black;
#declare HEDA_StringMarca               = "POV-Ray"

#declare HEDA_DefaultTexturaPrincipal   =
  texture               {
    pigment { White }
    normal  { bumps }
  }

#ifndef ( HEDA_TexturaPrincipal )
  #declare HEDA_TexturaPrincipal        =
    texture { HEDA_DefaultTexturaPrincipal }
#end

#declare HEDA_DefaultTexturaMetal   =
  texture               {
    pigment { Silver*0.8 }
    finish  { 
      metallic   
      ambient  0.4
      diffuse  0.4
    }
    normal              {
      bumps
    }
  }

#ifndef ( HEDA_TexturaMetal )
  #declare HEDA_TexturaMetal        =
    texture { HEDA_DefaultTexturaMetal }
#end

#declare HEDA_DefaultTexturaInferiorTapa   =
  texture               {
    pigment { Silver*0.6 }
    finish  { metallic }
    normal              {
      bumps
    }
  }

#ifndef ( HEDA_TexturaInferiorTapa )
  #declare HEDA_TexturaInferiorTapa        =
    texture { HEDA_DefaultTexturaInferiorTapa }
#end

#declare HEDA_DefaultTexturaSuperiorTapa   =
  texture               {
    pigment { Gray75 }
    normal              {
      bumps
    }
  }

#ifndef ( HEDA_TexturaSuperiorTapa )
  #declare HEDA_TexturaSuperiorTapa        =
    texture { HEDA_DefaultTexturaSuperiorTapa }
#end

#declare HEDA_DefaultTexturaPatas   =
  texture               {
    pigment { Gray10 }
    normal              {
      bumps
    }
  }

#ifndef ( HEDA_TexturaPatas )
  #declare HEDA_TexturaPatas        =
    texture { HEDA_DefaultTexturaPatas }
#end

#declare HEDA_DefaultTexturaCeramica   =
  texture               {
    pigment {  White }
  }

#ifndef ( HEDA_TexturaCeramica )
  #declare HEDA_TexturaCeramica        =
    texture { HEDA_DefaultTexturaCeramica }
#end

#declare HEDA_DefaultTexturaIndicador   =
  texture               {
    pigment {  Red }
  }

#ifndef ( HEDA_TexturaIndicador )
  #declare HEDA_TexturaIndicador        =
    texture { HEDA_DefaultTexturaIndicador }
#end

#declare HEDA_DefaultMaterialIncandescente   =
  material              {
    texture { T_Glass1 }
    texture               {
      pigment { Red transmit 0.9 }
    }
  }

#ifndef ( HEDA_MaterialIncandescente )
  #declare HEDA_MaterialIncandescente        =
    material { HEDA_DefaultMaterialIncandescente }
#end

#declare HEDA_DefaultMaterialVidrio   =
  material              {
    texture { T_Glass1 }
  }

#ifndef ( HEDA_MaterialVidrio )
  #declare HEDA_MaterialVidrio        =
    material { HEDA_DefaultMaterialVidrio }
#end

#declare HEDA_L                 = 0.001;

#macro HEDA_Rejilla( Largo, Ancho, Curvatura, Grueso, TotalRejillas )
  union                 {
    #local SeparacionRejilla    = Largo/( TotalRejillas+1 );
    #local Curvita       =
      difference           {
        torus              {
          Curvatura        , Grueso/2
        }
        plane              {
          x                , 0
        }
        plane              {
          z                , 0
        }
        translate          < Largo/2-Curvatura, 0, Ancho/2-Curvatura >
      }  // Curvita

    object               {
      Curvita
    }
    object               {
      Curvita
      scale              -1
    }
    object               {
      Curvita
      scale              <-1,1,1>
    }
    object               {
      Curvita
      scale              <1,1,-1>
    }
    cylinder             {
      ( Largo/2-Curvatura )*x,
      (-Largo/2+Curvatura )*x,
      Grueso/2
      translate         Ancho/2*z
    }
    cylinder             {
      ( Largo/2-Curvatura )*x,
      (-Largo/2+Curvatura )*x,
      Grueso/2
      translate         -Ancho/2*z
    }
    cylinder             {
      ( Ancho/2-Curvatura )*z,
      (-Ancho/2+Curvatura )*z,
      Grueso/2
      translate         Largo/2*x
    }
    cylinder             {
      ( Ancho/2-Curvatura )*z,
      (-Ancho/2+Curvatura )*z,
      Grueso/2
      translate         -Largo/2*x
    }
    #local C            = 0;
    #while ( C < TotalRejillas )
      cylinder          {
        -Ancho/2*z, +Ancho/2*z, Grueso/4
        translate       3*Grueso/4*z
        translate       (-Largo/2+( C+1 )*SeparacionRejilla )*x
      }
      #local C          = C+1;
    #end  // #while ( C < TotalRejillas )
  }  // union
#end  // #macro HEDA_Rejillla

#macro HEDA_Bandeja( Largo, Ancho, Alto, Grueso )
  union                 {
    object              {
      HEDA_Rejilla( Largo, Ancho, Ancho/10, Grueso, 0 )
    }  // object HEDA_Rejilla
    difference          {
      superellipsoid    {
        < 0.2, 0.2 >
        scale           < Largo, 2*Alto, Ancho >/2
      }
      superellipsoid    {
        < 0.2, 0.2 >
        scale           < Largo, 2*Alto, Ancho >/2-Grueso
      }
      plane             {
        -y , 0
      }
    }
  }  // union
#end

#macro HEDA_Tapa( Largo, Alto, Grueso, MaterialVidrio,
   TexturaInferior, TexturaSuperior, TexturaMetalica )
  union                 {
    box                 {
      <-Largo/2,0,-Grueso/2>,
      < Largo/2,Alto,+Grueso/2>
      material          {
        MaterialVidrio
      }
    }
    // borde inferior tapa
    union               {
      box               {
        <-Largo/2,0,-Grueso>,
        <+Largo/2,Alto/8,+Grueso>
      }
      box               {
        <+0.95*Largo/2,0,-Grueso>,
        <+Largo/2,Alto/4,+Grueso>
      }
      texture           {
        TexturaInferior
      }
    }  // union borde inferior tapa
    union               {
      difference        {
        box               {
          <-Largo/2,7*Alto/8,-Grueso/2>,
          <+Largo/2,  Alto  ,-Grueso  >
        }
        #local C        = 0;
        #while ( C < 2 )
          #local D      = 0;
          #while ( D < 3 )
            box         {
              <-0.75*Grueso/2,0,-0.75*Grueso/2>,
              <+0.75*Grueso/2,1.1*Alto,+0.75*Grueso/2>
              translate         -Grueso*z
              translate         -0.85*Largo/2*x+D*x*Largo*0.025
              texture   {
                TexturaSuperior
              }
              normal    {
                gradient x
              }
              #if ( C = 0 )
                scale   -x
              #end
            }
            #local D    = D+1;
          #end
          #local C      = C+1;
        #end

      }
      difference          {
        cone                {
          0, Largo/4,
          Alto/8*y, 0.9*Largo/4
        }
        cone              {
          -0.001*Alto*y, 0.975*Largo/4,
          1.001*Alto/8*y, 0.875*Largo/8
        }
        plane             {
          -z,Largo/16
        }
        scale             <1,1,0.2>
        translate         7*Alto/8*y
      }
      texture           {
        TexturaSuperior
      }
    }
    union               {
      box               {
        <-9*Largo/32,+15*Alto/16,-Grueso/2>,
        <-13*Largo/32,1.001*Alto,+3*Grueso/4>
      }
      box               {
        <+9*Largo/32,+15*Alto/16,-Grueso/2>,
        <+13*Largo/32,1.001*Alto,+3*Grueso/4>
      }
      texture           {
        TexturaMetalica
      }
    }  // union
  }  // union
#end

#macro HEDA_FormaBasica
  ( Frente, Alto, Profundidad, AnguloFrente, FactorCizalla )
  union                 {
    difference          {
      union             {
        superellipsoid    {
          <0.1,0.1>
        }
        superellipsoid    {
          <0.1,0.1>
          translate       -y
          matrix          <1,0,0,-FactorCizalla,1,0,0,0,1,0,0,0>
          translate       +y
        }
        scale             <Frente/2,Alto/2,2*Profundidad>
        translate         Alto/2*y
      }
      plane               {
        -z, 0
      }
      plane               {
        z, 0
        rotate            AnguloFrente*x
        translate         -Profundidad*z
      }
    }  // difference
  }  // union
#end  // #macro HEDA_FormaBasica

#macro HEDA_HornoPrincipal( Frente, Alto, Profundidad,
    AnguloFrente, GruesoPared, AnguloFrente,
    TexturaMetal, TexturaCeramica, MaterialIncandescente )
  union                 {
    difference          {
      box               {
        <-Frente/2,0,0>,
        <+Frente/2,Alto,-Profundidad>
      }
      box               {
        <-Frente/2+GruesoPared,GruesoPared,-GruesoPared>,
        <+Frente/2-GruesoPared,Alto-GruesoPared,-2*Profundidad>
      }
      plane             {
        z, 0
        rotate          AnguloFrente*x
        translate       -Profundidad*z
      }
    }
    #local C            = 0;
    #while ( C < 2 )
      union             {
        superellipsoid  {
          <0.3,0.3>
          scale         < GruesoPared/2, Alto/10, 3*Profundidad/10 >
          translate     <-Frente/2+GruesoPared,0.4*Alto,-Profundidad/2>
        }
        superellipsoid  {
          <0.3,0.3>
          scale         < GruesoPared/2, Alto/20, 3*Profundidad/10 >
          translate     <-Frente/2+GruesoPared,0.2*Alto,-Profundidad/2>
        }
        superellipsoid  {
          <0.3,0.3>
          scale         < GruesoPared/2, Alto/20, 3*Profundidad/10 >
          translate     <-Frente/2+GruesoPared,0.6*Alto,-Profundidad/2>
        }
        cylinder        {
          -Frente/20*x, +Frente/20*x, GruesoPared/2
          translate     <-0.4*Frente, GruesoPared, -0.8*Profundidad >
        }
        #if ( C = 0 )
          scale         -x
        #end
      }
      #local C          = C+1;
    #end
    #local BarraIncandescente   =
      union             {
        difference      {
          cylinder      {
            -Frente/2*x, Frente/2*x, GruesoPared
          }
          cylinder      {
            -( Frente/2-2*GruesoPared )*x,
            +( Frente/2-2*GruesoPared )*x,
            2*GruesoPared
          }
          texture       {
            TexturaCeramica
          }
        }
        cylinder        {
          -0.99*Frente/2*x, +0.99*Frente/2*x,
          GruesoPared/2
          material      {
            MaterialIncandescente
          }
        }
      }

    object              {
      BarraIncandescente
      translate         2*GruesoPared*y-Profundidad/2*z
    }
    object              {
      BarraIncandescente
      translate         ( AltoHorno-2*GruesoPared )*y-Profundidad/2*z
    }
    texture             {
      TexturaMetal
    }
  }  //
#end

#macro HEDA_HornoElectricoDomesticoAjustable(
    AnguloPerilla1, AnguloPerilla2, FactorPuerta, FactorBandeja,
    FrenteBasico, AltoBasico, ProfundidadBasico,
    GruesoPared, DiametroPerilla,
    TexturaPrincipal, TexturaMetal, TexturaCeramica, MaterialIncandescente,
    TexturaInferiorTapa, TexturaSuperiorTapa, MaterialVidrio,
    TexturaIndicador, TexturaPatas
  )
  union                 {
    #local AltoHorno    = AltoBasico*106/114;
    #local AltoPatas    = 0.050*AltoBasico;
    #local FactorCizalla        = 0.06;
    #local AnguloFrente = 10;
    #local FrenteHorno  = 214/264*FrenteBasico;
    #local BanderaTexto = HEDA_BanderaTexto;
    #local Perilla      =
      union             {
        cylinder        {
          0, +0.05*z, 1
        }
        difference      {
          sphere        {
            #local Radio                = 10;
            #local RadioM               = sqrt( Radio*Radio+1 );
            0, RadioM
            translate   +Radio*z
          }
          plane         {
            -z, 0
          }
        }
        prism           {
          cubic_spline
          0, -0.95, 9,
          < 0.15,-0.80 >,
          < 0.10, 0    >,
          < 0.15, 0.80 >,
          <-0.15, 0.80 >,
          <-0.10, 0    >,
          <-0.15,-0.80 >,
          < 0.15,-0.80 >,
          < 0.10, 0    >,
          < 0.15, 0.80 >
          rotate        +90*x
        }
        cylinder        {
          0.25*y, 0.80*y, 0.05
          translate     -0.95*z
        }
        translate       -0.05*z
      }
    difference          {
      union             {
        object            {
          HEDA_FormaBasica( FrenteBasico, AltoBasico, ProfundidadBasico,
                  AnguloFrente, FactorCizalla )
        }
        difference      {
          object        {
            HEDA_FormaBasica( 0.99*FrenteBasico, 0.99*AltoBasico,
              1.05*ProfundidadBasico, AnguloFrente,FactorCizalla )
          }
          box           {
            <-FrenteHorno/2,-0.1*AltoHorno,+0.1*ProfundidadBasico>,
            <+FrenteHorno/2,+1.1*AltoBasico,-1.5*ProfundidadBasico>
            translate   -( FrenteBasico-FrenteHorno )/4*x
          }
        }
      }
      box               {
        <-FrenteHorno/2,-0.1*AltoHorno,+0.1*ProfundidadBasico>,
        <+FrenteHorno/2,AltoHorno,-1.5*ProfundidadBasico>
        translate       -(FrenteBasico-FrenteHorno)/4*x
      }
      cylinder          {
        +0.02*ProfundidadBasico*z, -0.1*ProfundidadBasico*z,
        DiametroPerilla/2
        translate       +0.60*AltoBasico*y
        rotate          AnguloFrente*x
        translate       +0.875*FrenteBasico/2*x
                        -1.05*ProfundidadBasico*z                        
      }
      cylinder          {
        +0.02*ProfundidadBasico*z, -0.1*ProfundidadBasico*z,
        DiametroPerilla/2
        translate       +0.25*AltoBasico*y
        rotate          AnguloFrente*x
        translate       +0.875*FrenteBasico/2*x
                        -1.05*ProfundidadBasico*z                        
      }
      cylinder          {
        +0.02*ProfundidadBasico*z, -0.1*ProfundidadBasico*z,
        DiametroPerilla/6
        scale           <1,0.5,1>
        rotate          -20*z
        translate       +0.875*AltoBasico*y
        rotate          AnguloFrente*x
        translate       +0.875*FrenteBasico/2*x
                        -1.05*ProfundidadBasico*z                        
      }
      texture           {
        TexturaPrincipal
      }
    }
    // Perillas y texto
        union               {
      object            {
        Perilla
        scale           DiametroPerilla/2*0.95*(x+y+0.5*z)
        rotate          AnguloPerilla1*z
      }
      #if ( BanderaTexto )
        cylinder          {
          0, -0.125*DiametroPerilla*z, 0.025*DiametroPerilla
          translate       0.55*DiametroPerilla*y
          pigment { HEDA_ColorTexto }
        }
        text              {
          ttf "timrom.ttf" "AA" 1,0
          scale   0.100*DiametroPerilla
          translate -0.150*DiametroPerilla*z+0.625*DiametroPerilla*y-0.050*DiametroPerilla*x
          pigment { HEDA_ColorTexto }
        }
        cylinder          {
          0, -0.125*DiametroPerilla*z, 0.025*DiametroPerilla
          translate       0.55*DiametroPerilla*x
          pigment { HEDA_ColorTexto }
        }
        text              {
          ttf "timrom.ttf" "A" 1,0
          scale   0.100*DiametroPerilla
          translate -0.150*DiametroPerilla*z+0.625*DiametroPerilla*x-0.050*DiametroPerilla*y
          pigment { HEDA_ColorTexto }
        }
      #end
      translate       +0.60*AltoBasico*y
      rotate          AnguloFrente*x
      translate       +0.875*FrenteBasico/2*x
                        -1.03*ProfundidadBasico*z
      texture { TexturaSuperiorTapa }
    }
    #if ( BanderaTexto )
      text              {
        ttf "timrom.ttf" HEDA_StringMarca 1,0
        scale   0.150*DiametroPerilla
        translate -0.150*DiametroPerilla*z
        translate       +0.92*AltoBasico*y-0.050*FrenteBasico*x
        rotate          AnguloFrente*x
        translate       +0.875*FrenteBasico/2*x
                        -1.03*ProfundidadBasico*z
        pigment { HEDA_ColorTexto }
      }
    #end
    union               {
      object            {
        Perilla
        scale           DiametroPerilla/2*0.95*(x+y+0.5*z)
        rotate          AnguloPerilla2*z
      }
      #if ( BanderaTexto )
        #local C        = 0;
        #while ( C < 8 )
          cylinder          {
            0, -0.125*DiametroPerilla*z, 0.025*DiametroPerilla
            translate       0.55*DiametroPerilla*y
            rotate        45*C*z
            pigment { HEDA_ColorTexto }
          }
          #if ( mod( C, 2 ) = 0 )
            text              {
              ttf "timrom.ttf" str(C*10, 2, 0 ) 1,0
              scale   0.100*DiametroPerilla
              #local Ubicar = -0.150*DiametroPerilla*z+0.650*DiametroPerilla*y-0.100*DiametroPerilla*x;
              #local Ubicar = vaxis_rotate( Ubicar, z, 45*C );
              translate   Ubicar
              pigment { HEDA_ColorTexto }
            }
          #end
          #local C      = C+1;
        #end
      #end
      translate       +0.25*AltoBasico*y
      rotate          AnguloFrente*x
      translate       +0.875*FrenteBasico/2*x
                        -1.03*ProfundidadBasico*z
      texture { TexturaSuperiorTapa }
    }
    union               {
      sphere            {
        +0.02*ProfundidadBasico*z,
        0.7*DiametroPerilla/6
        scale           <1,0.5,1>
        rotate          -20*z
      }
      translate       +0.875*AltoBasico*y
      rotate          AnguloFrente*x
      translate       +0.875*FrenteBasico/2*x
                      -1.05*ProfundidadBasico*z
      texture { TexturaIndicador }
    }
    union               {
      object            {
        HEDA_HornoPrincipal( FrenteHorno, AltoHorno, ProfundidadBasico,
          AnguloFrente, GruesoPared, AnguloFrente,
          TexturaMetal, TexturaCeramica, MaterialIncandescente )
      }
      object            {
        HEDA_Rejilla( 0.96*FrenteHorno-2*GruesoPared, ProfundidadBasico*0.8,
          0.0275*ProfundidadBasico, 0.010*FrenteHorno, 13 )
        translate       0.275*AltoHorno*y-0.500*ProfundidadBasico*z
        translate   -0.65*ProfundidadBasico*z*FactorBandeja*0.50
      }
      object            {
        HEDA_Bandeja( 0.9*FrenteHorno-2*GruesoPared, 0.65*ProfundidadBasico,
         0.1*AltoHorno, 0.005*FrenteHorno )
        translate       0.275*AltoHorno*y-0.500*ProfundidadBasico*z
                        +0.010*FrenteHorno*y+0.1*AltoHorno*y
        translate   -0.65*ProfundidadBasico*z*FactorBandeja
      }
      object            {
        HEDA_Tapa( 0.975*FrenteHorno,
          AltoHorno/cos( radians( AnguloFrente ) ),
          0.015*ProfundidadBasico,
          MaterialVidrio,
          TexturaInferiorTapa, TexturaSuperiorTapa, TexturaMetal )
//        translate       -0.05*y
        translate       -0.015*ProfundidadBasico*z
        rotate          AnguloFrente*x
        rotate          -( 90+AnguloFrente )*x*FactorPuerta
//        translate       +0.05*y
        translate       -1.00*ProfundidadBasico*z
      }
      
      translate         -( FrenteBasico-FrenteHorno )/4*x
      texture           { TexturaMetal }
    }
    #local C            = 0;
    #while ( C < 4 )
      difference            {
        cylinder            {
            -0.40*AltoPatas*x, 0.40*AltoPatas*x,
              AltoPatas
        }
        plane               {
              -y, 0
        }
        translate           +0.40*FrenteBasico*x+0.40*ProfundidadBasico*z
        #switch ( C )
              #case(0)
              #break
              #case(1)
                scale -x
              #break
              #case(2)
                scale   -z
              #break
              #case(3)
                scale   -x-z
              #break
          #end
          translate           -0.50*ProfundidadBasico*z
          texture       { TexturaPatas }
        }  // difference
      #local C        = C+1;
    #end
    texture             {
      TexturaPrincipal
    }
    translate           AltoPatas*y
  }
#end  // #macro HEDA_HornoElectricoDomesticoAjustable

#macro HEDA_Horno( AnguloPerilla1, AnguloPerilla2,
                FactorPuerta, FactorBandeja )
  object                {
    #local L            = HEDA_L;
    #local FrenteBasico = 264*L;
    #local AltoBasico   = 114*L;
    #local ProfundidadBasico            = 157*L;
    #local GruesoPared  = 6*L;
    #local DiametroPerilla              = 28.5*L;
    HEDA_HornoElectricoDomesticoAjustable(
      AnguloPerilla1, AnguloPerilla2, FactorPuerta, FactorBandeja,
      FrenteBasico, AltoBasico, ProfundidadBasico,
      GruesoPared, DiametroPerilla,
      HEDA_TexturaPrincipal, HEDA_TexturaMetal,
      HEDA_TexturaCeramica, HEDA_MaterialIncandescente,
      HEDA_TexturaInferiorTapa, HEDA_TexturaSuperiorTapa,
      HEDA_MaterialVidrio, HEDA_TexturaIndicador,
      HEDA_TexturaPatas
    )
  }
#end
